@@ -4,7 +4,7 @@ package Proch::N50;
 use 5.014;
 use warnings;
 
-$Proch::N50::VERSION = '0.09';
+$Proch::N50::VERSION = '0.10';
 
 use JSON::PP;
 use FASTX::Reader;
@@ -61,9 +61,9 @@ sub getStats {
 
     my $basename = basename($file);
 
-    $answer->{N50}      = $n50;
-    $answer->{min}      = $min;
-    $answer->{max}      = $max;
+    $answer->{N50}      = $n50 + 0;
+    $answer->{min}      = $min + 0;
+    $answer->{max}      = $max + 0;
     $answer->{seqs}     = $n;
     $answer->{size}     = $slen;
     $answer->{filename} = $basename;
@@ -207,7 +207,7 @@ Proch::N50 - a small module to calculate N50 (total size, and total number of se
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -241,8 +241,11 @@ version 0.09
   #    "seqs" : 6,
   #    <...>
   #    "filename" : "small_test.fa",
-  #    "N50" : "65",
+  #    "N50" : 65,
   # }
+  # Directly ask for the JSON object only:
+  my $json = jsonStats($filepath);
+  print $json; 
 
 =head1 METHODS
 
@@ -335,15 +338,35 @@ Returns N50, min and max lengths.
 
 =head1 Dependencies
 
+=head2 Module (N50.pm)
+
 =over 4
 
-=item L<JSON::PP> (core)
+=item L<JSON::PP> (core module, required)
+
+=back
+
+=head2 Implementation (n50.pl)
+
+=over 4
+
+=item L<Term::ANSIColor> 
 
 =back
 
 =over 4
 
-=item L<Term::ANSIColor> (optional)  for the n50.pl script
+=item L<JSON>
+
+(optional) when using C<--format JSON>
+
+=back
+
+=over 4
+
+=item L<Text::ASCIITable>
+
+(optional) when using C<--format screen>. This might be substituted by a different module in the future.
 
 =back
 
